# L2M2: Simple LLM Manager for Python

[L2M2](https://pypi.org/project/l2m2/) ("LLM Manager" &rarr; "LLMM" &rarr; "L2M2") is a simple LLM manager for Python.

I'll complete the rest of this readme soon.
